@@ -18,10 +18,7 @@ class _get:
     def __init__(self, ws, wsUrl, wsData, headers=None, encryption=None, identifiers=None, timeout=None, debug=False):
         if wsUrl != wsData["CURRENT_URL"]:
             wsData["CURRENT_URL"] = wsUrl
-            if headers == None:
-                ws = create_connection(wsUrl)
-            else:
-                ws = create_connection(wsUrl, header=headers)
+            ws = create_connection(wsUrl, header=headers, enable_multithread=True)
 
         keys = []
         values = []
@@ -68,10 +65,7 @@ class _post:
 
         if wsUrl != wsData["CURRENT_URL"]:
             wsData["CURRENT_URL"] = wsUrl
-            if headers == None:
-                ws = create_connection(wsUrl)
-            else:
-                ws = create_connection(wsUrl, header=headers)
+            ws = create_connection(wsUrl, header=headers, enable_multithread=True)
 
         dataFormatted = JSON.dumps(data) if type(data) == dict else data if data != None else JSON.dumps(json)
         ws.send(dataFormatted)
@@ -164,4 +158,4 @@ class Session:
         except Exception:
             pass
         time.cancel()
-        self.ws.close()
\ No newline at end of file
+        self.ws.close()
